@@ -35,6 +35,7 @@ public:
     Private(Config *parent)
         : QObject(parent)
         , valid(true)
+        , supportedFeatures(Config::Feature::None)
         , q(parent)
     { }
 
@@ -86,6 +87,7 @@ public:
     ScreenPtr screen;
     OutputPtr primaryOutput;
     OutputList outputs;
+    Features supportedFeatures;
 
 private:
     Config *q;
@@ -234,6 +236,16 @@ OutputPtr Config::output(int outputId) const
     return d->outputs.value(outputId);
 }
 
+Config::Features Config::supportedFeatures() const
+{
+    return d->supportedFeatures;
+}
+
+void Config::setSupportedFeatures(const Config::Features &features)
+{
+    d->supportedFeatures = features;
+}
+
 OutputList Config::outputs() const
 {
     return d->outputs;
@@ -351,4 +363,4 @@ void Config::apply(const ConfigPtr& other)
     setValid(other->isValid());
 }
 
-#include "config.moc"
\ No newline at end of file
+#include "config.moc"
